#version 330 core 

uniform sampler2D texBuf;
uniform float sysTime;
uniform vec2 resolution;
uniform int dark;

in vec2 vTexCoord;

out vec4 fragColor;

const float blurSize = 1.0/256.0;
const float intensity = 10;

void main()
{
   if (dark == 0) {
      vec3 texColor = texture(texBuf,vTexCoord).xyz;
      fragColor = vec4(texColor,1.0);

   } else {
      vec4 sum = vec4(0);
      int i, j;

      // x blur - horizontal
      // take nine samples, with the distance blurSize between them
      sum += texture(texBuf, vec2(vTexCoord.x - 5.0*blurSize, vTexCoord.y)) * 0.02;
      sum += texture(texBuf, vec2(vTexCoord.x - 4.0*blurSize, vTexCoord.y)) * 0.05;
      sum += texture(texBuf, vec2(vTexCoord.x - 3.0*blurSize, vTexCoord.y)) * 0.09;
      sum += texture(texBuf, vec2(vTexCoord.x - 2.0*blurSize, vTexCoord.y)) * 0.12;
      sum += texture(texBuf, vec2(vTexCoord.x - blurSize, vTexCoord.y)) * 0.15;
      sum += texture(texBuf, vec2(vTexCoord.x, vTexCoord.y)) * 0.16;
      sum += texture(texBuf, vec2(vTexCoord.x + blurSize, vTexCoord.y)) * 0.15;
      sum += texture(texBuf, vec2(vTexCoord.x + 2.0*blurSize, vTexCoord.y)) * 0.12;
      sum += texture(texBuf, vec2(vTexCoord.x + 3.0*blurSize, vTexCoord.y)) * 0.09;
      sum += texture(texBuf, vec2(vTexCoord.x + 4.0*blurSize, vTexCoord.y)) * 0.05;
       sum += texture(texBuf, vec2(vTexCoord.x + 5.0*blurSize, vTexCoord.y)) * 0.01;
   	
   	// y blur - vertical
      // take nine samples, with the distance blurSize between them
      sum += texture(texBuf, vec2(vTexCoord.x, vTexCoord.y - 5.0*blurSize)) * 0.05;
      sum += texture(texBuf, vec2(vTexCoord.x, vTexCoord.y - 4.0*blurSize)) * 0.05;
      sum += texture(texBuf, vec2(vTexCoord.x, vTexCoord.y - 3.0*blurSize)) * 0.09;
      sum += texture(texBuf, vec2(vTexCoord.x, vTexCoord.y - 2.0*blurSize)) * 0.12;
      sum += texture(texBuf, vec2(vTexCoord.x, vTexCoord.y - blurSize)) * 0.15;
      sum += texture(texBuf, vec2(vTexCoord.x, vTexCoord.y)) * 0.16;
      sum += texture(texBuf, vec2(vTexCoord.x, vTexCoord.y + blurSize)) * 0.15;
      sum += texture(texBuf, vec2(vTexCoord.x, vTexCoord.y + 2.0*blurSize)) * 0.12;
      sum += texture(texBuf, vec2(vTexCoord.x, vTexCoord.y + 3.0*blurSize)) * 0.09;
      sum += texture(texBuf, vec2(vTexCoord.x, vTexCoord.y + 4.0*blurSize)) * 0.05;
      sum += texture(texBuf, vec2(vTexCoord.x, vTexCoord.y + 5.0*blurSize)) * 0.02;

      // glow over time
      if(sin(sysTime)*10 > 0.0)
          fragColor = sum * sin(sysTime)+ texture(texBuf, vTexCoord);
      else
   	   fragColor = sum * -sin(sysTime)+ texture(texBuf, vTexCoord);
   }
}